package com.memorynotfound.util.locale;

import java.util.*;
import java.util.stream.Collectors;

public class ListCountriesOwnLanguage {

    public static void main(String... args){

        // Get all available locales
        List<Locale> availableLocales = Arrays.asList(Locale.getAvailableLocales());

        // Get all available ISO countries
        String[] countryCodes = Locale.getISOCountries();

        // Create a collection of all available countries
        List<Country> countries = new ArrayList<Country>();

        // Map ISO countries to custom country object
        for (String countryCode : countryCodes){

            Optional<Locale> candidate = availableLocales.stream()
                    .filter(l -> l.getCountry().equals(countryCode))
                    .collect(Collectors.reducing((a, b) -> null));

            Locale locale;
            if (candidate.isPresent()){
                locale = candidate.get();
            } else {
                System.out.println("could not find resource for: " + countryCode + " mapping default lang");
                locale = new Locale("", countryCode);
            }

            String iso = locale.getISO3Country();
            String code = locale.getCountry();
            String country = locale.getDisplayCountry(locale);
            countries.add(new Country(iso, code, country));
        }

        // Sort countries
        Collections.sort(countries);

        // Loop over collection of countries and print to console
        countries.forEach((System.out::println));

        // Print out available locales
        System.out.println("available locales: " + availableLocales.size());

        // print total number of countries
        System.out.println("found: " + countries.size() + " countries");

    }

}
